Index: /trunk/src/VBox/Devices/Audio/DrvHostDSound.cpp
===================================================================
--- /trunk/src/VBox/Devices/Audio/DrvHostDSound.cpp	(revision 68084)
+++ /trunk/src/VBox/Devices/Audio/DrvHostDSound.cpp	(revision 68085)
@@ -1549,11 +1549,11 @@
  */
 int drvHostDSoundStreamPlay(PPDMIHOSTAUDIO pInterface,
-                            PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cbBuf, uint32_t *pcbWritten)
+                            PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cxBuf, uint32_t *pcxWritten)
 {
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
     AssertPtrReturn(pvBuf,      VERR_INVALID_POINTER);
-    AssertReturn(cbBuf,         VERR_INVALID_PARAMETER);
-    /* pcbRead is optional. */
+    AssertReturn(cxBuf,         VERR_INVALID_PARAMETER);
+    /* pcxWritten is optional. */
 
     PDRVHOSTDSOUND pThis     = PDMIHOSTAUDIO_2_DRVHOSTDSOUND(pInterface);
@@ -1587,5 +1587,5 @@
         cbFree     -= cbSample;
 
-        uint32_t cbLive = cbBuf;
+        uint32_t cbLive = cxBuf;
 
         /* Do not write more than available space in the DirectSound playback buffer. */
@@ -1671,6 +1671,6 @@
     if (RT_SUCCESS(rc))
     {
-        if (pcbWritten)
-            *pcbWritten = cbWrittenTotal;
+        if (pcxWritten)
+            *pcxWritten = cbWrittenTotal;
     }
     else
@@ -1782,5 +1782,5 @@
  */
 int drvHostDSoundStreamCapture(PPDMIHOSTAUDIO pInterface,
-                               PPDMAUDIOBACKENDSTREAM pStream, void *pvBuf, uint32_t cbBuf, uint32_t *pcbRead)
+                               PPDMAUDIOBACKENDSTREAM pStream, void *pvBuf, uint32_t cxBuf, uint32_t *pcxRead)
 {
 
@@ -1788,5 +1788,5 @@
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
     AssertPtrReturn(pvBuf,      VERR_INVALID_POINTER);
-    AssertReturn(cbBuf,         VERR_INVALID_PARAMETER);
+    AssertReturn(cxBuf,         VERR_INVALID_PARAMETER);
 
     PDRVHOSTDSOUND pThis     = PDMIHOSTAUDIO_2_DRVHOSTDSOUND(pInterface);
@@ -1834,5 +1834,5 @@
             break;
 
-        if (cbBuf == 0)
+        if (cxBuf == 0)
         {
             DSLOGF(("DSound: Capture buffer full\n"));
@@ -1841,8 +1841,8 @@
 
         DSLOGF(("DSound: Capture cbBuf=%RU32, offCurPos=%ld, offCaptureBufRead=%ld, cbToCapture=%ld\n",
-                cbBuf, offCurPos, pStreamDS->In.offCaptureBufRead, cbToCapture));
+                cxBuf, offCurPos, pStreamDS->In.offCaptureBufRead, cbToCapture));
 
         /* No need to fetch more samples than mix buffer can receive. */
-        cbToCapture = RT_MIN(cbToCapture, cbBuf);
+        cbToCapture = RT_MIN(cbToCapture, cxBuf);
 
         /* Lock relevant range in the DirectSound capture buffer. */
@@ -1885,6 +1885,6 @@
     if (RT_SUCCESS(rc))
     {
-        if (pcbRead)
-            *pcbRead = cbReadTotal;
+        if (pcxRead)
+            *pcxRead = cbReadTotal;
     }
     else
Index: /trunk/src/VBox/Devices/Audio/DrvHostDebugAudio.cpp
===================================================================
--- /trunk/src/VBox/Devices/Audio/DrvHostDebugAudio.cpp	(revision 68084)
+++ /trunk/src/VBox/Devices/Audio/DrvHostDebugAudio.cpp	(revision 68085)
@@ -213,6 +213,6 @@
  */
 static DECLCALLBACK(int) drvHostDebugAudioStreamPlay(PPDMIHOSTAUDIO pInterface,
-                                                     PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cbBuf,
-                                                     uint32_t *pcbWritten)
+                                                     PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cxBuf,
+                                                     uint32_t *pcxWritten)
 {
     RT_NOREF(pInterface);
@@ -221,5 +221,5 @@
     uint32_t cbWrittenTotal = 0;
 
-    uint32_t cbAvail = cbBuf;
+    uint32_t cbAvail = cxBuf;
     while (cbAvail)
     {
@@ -249,6 +249,6 @@
     }
 
-    if (pcbWritten)
-        *pcbWritten = cbWrittenTotal;
+    if (pcxWritten)
+        *pcxWritten = cbWrittenTotal;
 
     return VINF_SUCCESS;
@@ -260,11 +260,11 @@
  */
 static DECLCALLBACK(int) drvHostDebugAudioStreamCapture(PPDMIHOSTAUDIO pInterface, PPDMAUDIOBACKENDSTREAM pStream,
-                                                        void *pvBuf, uint32_t cbBuf, uint32_t *pcbRead)
-{
-    RT_NOREF(pInterface, pStream, pvBuf, cbBuf);
+                                                        void *pvBuf, uint32_t cxBuf, uint32_t *pcxRead)
+{
+    RT_NOREF(pInterface, pStream, pvBuf, cxBuf);
 
     /* Never capture anything. */
-    if (pcbRead)
-        *pcbRead = 0;
+    if (pcxRead)
+        *pcxRead = 0;
 
     return VINF_SUCCESS;
Index: /trunk/src/VBox/Devices/Audio/DrvHostNullAudio.cpp
===================================================================
--- /trunk/src/VBox/Devices/Audio/DrvHostNullAudio.cpp	(revision 68084)
+++ /trunk/src/VBox/Devices/Audio/DrvHostNullAudio.cpp	(revision 68085)
@@ -135,10 +135,10 @@
  */
 static DECLCALLBACK(int) drvHostNullAudioStreamPlay(PPDMIHOSTAUDIO pInterface, PPDMAUDIOBACKENDSTREAM pStream,
-                                                    const void *pvBuf, uint32_t cbBuf, uint32_t *pcbWritten)
+                                                    const void *pvBuf, uint32_t cxBuf, uint32_t *pcxWritten)
 {
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
     AssertPtrReturn(pvBuf,      VERR_INVALID_POINTER);
-    AssertReturn(cbBuf,         VERR_INVALID_PARAMETER);
+    AssertReturn(cxBuf,         VERR_INVALID_PARAMETER);
 
     RT_NOREF(pInterface, pStream, pvBuf);
@@ -146,6 +146,6 @@
     /* Note: No copying of samples needed here, as this a NULL backend. */
 
-    if (pcbWritten)
-        *pcbWritten = cbBuf; /* Return all bytes as written. */
+    if (pcxWritten)
+        *pcxWritten = cxBuf; /* Return all bytes as written. */
 
     return VINF_SUCCESS;
@@ -157,13 +157,13 @@
  */
 static DECLCALLBACK(int) drvHostNullAudioStreamCapture(PPDMIHOSTAUDIO pInterface, PPDMAUDIOBACKENDSTREAM pStream,
-                                                       void *pvBuf, uint32_t cbBuf, uint32_t *pcbRead)
+                                                       void *pvBuf, uint32_t cxBuf, uint32_t *pcxRead)
 {
     RT_NOREF(pInterface, pStream);
 
     /* Return silence. */
-    RT_BZERO(pvBuf, cbBuf);
-
-    if (pcbRead)
-        *pcbRead = cbBuf;
+    RT_BZERO(pvBuf, cxBuf);
+
+    if (pcxRead)
+        *pcxRead = cxBuf;
 
     return VINF_SUCCESS;
Index: /trunk/src/VBox/Devices/Audio/DrvHostOSSAudio.cpp
===================================================================
--- /trunk/src/VBox/Devices/Audio/DrvHostOSSAudio.cpp	(revision 68084)
+++ /trunk/src/VBox/Devices/Audio/DrvHostOSSAudio.cpp	(revision 68085)
@@ -410,5 +410,5 @@
  */
 static DECLCALLBACK(int) drvHostOSSAudioStreamCapture(PPDMIHOSTAUDIO pInterface, PPDMAUDIOBACKENDSTREAM pStream,
-                                                      void *pvBuf, uint32_t cbBuf, uint32_t *pcbRead)
+                                                      void *pvBuf, uint32_t cxBuf, uint32_t *pcxRead)
 {
     RT_NOREF(pInterface);
@@ -419,5 +419,5 @@
     int rc = VINF_SUCCESS;
 
-    size_t cbToRead = RT_MIN(pStreamOSS->cbBuf, cbBuf);
+    size_t cbToRead = RT_MIN(pStreamOSS->cbBuf, cxBuf);
 
     LogFlowFunc(("cbToRead=%zi\n", cbToRead));
@@ -479,6 +479,6 @@
     if (RT_SUCCESS(rc))
     {
-        if (pcbRead)
-            *pcbRead = cbReadTotal;
+        if (pcxRead)
+            *pcxRead = cbReadTotal;
     }
 
@@ -798,6 +798,6 @@
  */
 static DECLCALLBACK(int) drvHostOSSAudioStreamPlay(PPDMIHOSTAUDIO pInterface,
-                                                   PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cbBuf,
-                                                   uint32_t *pcbWritten)
+                                                   PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cxBuf,
+                                                   uint32_t *pcxWritten)
 {
     RT_NOREF(pInterface);
@@ -815,5 +815,5 @@
     do
     {
-        uint32_t cbAvail = cbBuf;
+        uint32_t cbAvail = cxBuf;
         uint32_t cbToWrite;
 
@@ -838,5 +838,5 @@
                 cbData = cntinfo.ptr - pStreamOSS->old_optr;
             else
-                cbData = cbBuf + cntinfo.ptr - pStreamOSS->old_optr;
+                cbData = cxBuf + cntinfo.ptr - pStreamOSS->old_optr;
             Assert(cbData >= 0);
 
@@ -855,8 +855,8 @@
             }
 
-            if ((size_t)abinfo.bytes > cbBuf)
-            {
-                LogRel2(("OSS: Warning: Too big output size (%d > %RU32), limiting to %RU32\n", abinfo.bytes, cbBuf, cbBuf));
-                abinfo.bytes = cbBuf;
+            if ((size_t)abinfo.bytes > cxBuf)
+            {
+                LogRel2(("OSS: Warning: Too big output size (%d > %RU32), limiting to %RU32\n", abinfo.bytes, cxBuf, cxBuf));
+                abinfo.bytes = cxBuf;
                 /* Keep going. */
             }
@@ -864,5 +864,5 @@
             if (abinfo.bytes < 0)
             {
-                LogRel2(("OSS: Warning: Invalid available size (%d vs. %RU32)\n", abinfo.bytes, cbBuf));
+                LogRel2(("OSS: Warning: Invalid available size (%d vs. %RU32)\n", abinfo.bytes, cxBuf));
                 rc = VERR_INVALID_PARAMETER;
                 break;
@@ -921,6 +921,6 @@
     if (RT_SUCCESS(rc))
     {
-        if (pcbWritten)
-            *pcbWritten = cbWrittenTotal;
+        if (pcxWritten)
+            *pcxWritten = cbWrittenTotal;
     }
 
Index: /trunk/src/VBox/Devices/Audio/DrvHostValidationKit.cpp
===================================================================
--- /trunk/src/VBox/Devices/Audio/DrvHostValidationKit.cpp	(revision 68084)
+++ /trunk/src/VBox/Devices/Audio/DrvHostValidationKit.cpp	(revision 68085)
@@ -243,6 +243,6 @@
  */
 static DECLCALLBACK(int) drvHostVaKitAudioStreamPlay(PPDMIHOSTAUDIO pInterface,
-                                                     PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cbBuf,
-                                                     uint32_t *pcbWritten)
+                                                     PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cxBuf,
+                                                     uint32_t *pcxWritten)
 {
     PDRVHOSTVAKITAUDIO pDrv       = RT_FROM_MEMBER(pInterface, DRVHOSTVAKITAUDIO, IHostAudio);
@@ -265,5 +265,5 @@
 
     // Microseconds are used everythere below
-    uint32_t sBuf = cbBuf >> pStreamDbg->pCfg->Props.cShift;
+    uint32_t sBuf = cxBuf >> pStreamDbg->pCfg->Props.cShift;
     cch = RTStrPrintf(szTimingInfo, sizeof(szTimingInfo), "%d %d %d %d\n",
         (uint32_t)(tsSinceStart / 1000), // Host time elapsed since Guest submitted the first buffer for playback
@@ -277,9 +277,9 @@
    // pStreamDbg->Out.tsLastPlayed = PDMDrvHlpTMGetVirtualTime(pDrv->pDrvIns);;
 
-    int rc2 = DrvAudioHlpWAVFileWrite(&pStreamDbg->File, pvBuf, cbBuf, 0 /* fFlags */);
+    int rc2 = DrvAudioHlpWAVFileWrite(&pStreamDbg->File, pvBuf, cxBuf, 0 /* fFlags */);
     if (RT_FAILURE(rc2))
         LogRel(("DebugAudio: Writing output failed with %Rrc\n", rc2));
 
-    *pcbWritten = cbBuf;
+    *pcxWritten = cxBuf;
 
     return VINF_SUCCESS;
@@ -291,11 +291,12 @@
  */
 static DECLCALLBACK(int) drvHostVaKitAudioStreamCapture(PPDMIHOSTAUDIO pInterface,
-                                                        PPDMAUDIOBACKENDSTREAM pStream, void *pvBuf, uint32_t cbBuf, uint32_t *pcbRead)
-{
-    RT_NOREF(pInterface, pStream, pvBuf, cbBuf);
+                                                        PPDMAUDIOBACKENDSTREAM pStream, void *pvBuf, uint32_t cxBuf,
+                                                        uint32_t *pcxRead)
+{
+    RT_NOREF(pInterface, pStream, pvBuf, cxBuf);
 
     /* Never capture anything. */
-    if (pcbRead)
-        *pcbRead = 0;
+    if (pcxRead)
+        *pcxRead = 0;
 
     return VINF_SUCCESS;
Index: /trunk/src/VBox/Devices/Audio/DrvHostALSAAudio.cpp
===================================================================
--- /trunk/src/VBox/Devices/Audio/DrvHostALSAAudio.cpp	(revision 68084)
+++ /trunk/src/VBox/Devices/Audio/DrvHostALSAAudio.cpp	(revision 68085)
@@ -1008,10 +1008,10 @@
  */
 static DECLCALLBACK(int) drvHostALSAAudioStreamCapture(PPDMIHOSTAUDIO pInterface, PPDMAUDIOBACKENDSTREAM pStream,
-                                                       void *pvBuf, uint32_t cbBuf, uint32_t *pcbRead)
+                                                       void *pvBuf, uint32_t cxBuf, uint32_t *pcxRead)
 {
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
     AssertPtrReturn(pvBuf,      VERR_INVALID_POINTER);
-    AssertReturn(cbBuf,         VERR_INVALID_PARAMETER);
+    AssertReturn(cxBuf,         VERR_INVALID_PARAMETER);
     /* pcbRead is optional. */
 
@@ -1035,5 +1035,5 @@
         {
             case SND_PCM_STATE_PREPARED:
-                cAvail = PDMAUDIOSTREAMCFG_B2S(pCfg, cbBuf);
+                cAvail = PDMAUDIOSTREAMCFG_B2S(pCfg, cxBuf);
                 break;
 
@@ -1055,6 +1055,6 @@
         if (!cAvail)
         {
-            if (pcbRead)
-                *pcbRead = 0;
+            if (pcxRead)
+                *pcxRead = 0;
             return VINF_SUCCESS;
         }
@@ -1065,5 +1065,5 @@
      * the mixer buffer.
      */
-    size_t cbToRead = RT_MIN((size_t)PDMAUDIOSTREAMCFG_S2B(pCfg, cAvail), cbBuf);
+    size_t cbToRead = RT_MIN((size_t)PDMAUDIOSTREAMCFG_S2B(pCfg, cAvail), cxBuf);
 
     LogFlowFunc(("cbToRead=%zu, cAvail=%RI32\n", cbToRead, cAvail));
@@ -1140,6 +1140,6 @@
     if (RT_SUCCESS(rc))
     {
-        if (pcbRead)
-            *pcbRead = cbReadTotal;
+        if (pcxRead)
+            *pcxRead = cbReadTotal;
     }
 
@@ -1151,11 +1151,11 @@
  */
 static DECLCALLBACK(int) drvHostALSAAudioStreamPlay(PPDMIHOSTAUDIO pInterface, PPDMAUDIOBACKENDSTREAM pStream,
-                                                    const void *pvBuf, uint32_t cbBuf, uint32_t *pcbWritten)
+                                                    const void *pvBuf, uint32_t cxBuf, uint32_t *pcxWritten)
 {
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
     AssertPtrReturn(pvBuf,      VERR_INVALID_POINTER);
-    AssertReturn(cbBuf,         VERR_INVALID_PARAMETER);
-    /* pcbWritten is optional. */
+    AssertReturn(cxBuf,         VERR_INVALID_PARAMETER);
+    /* pcxWritten is optional. */
 
     PALSAAUDIOSTREAM pStreamALSA = (PALSAAUDIOSTREAM)pStream;
@@ -1186,6 +1186,6 @@
 
         /* Do not write more than available. */
-        if (cbToWrite > cbBuf)
-            cbToWrite = cbBuf;
+        if (cbToWrite > cxBuf)
+            cbToWrite = cxBuf;
 
         memcpy(pStreamALSA->pvBuf, pvBuf, cbToWrite);
@@ -1257,6 +1257,6 @@
     if (RT_SUCCESS(rc))
     {
-        if (pcbWritten)
-            *pcbWritten = cbWrittenTotal;
+        if (pcxWritten)
+            *pcxWritten = cbWrittenTotal;
     }
 
Index: /trunk/src/VBox/Devices/Audio/DrvHostCoreAudio.cpp
===================================================================
--- /trunk/src/VBox/Devices/Audio/DrvHostCoreAudio.cpp	(revision 68084)
+++ /trunk/src/VBox/Devices/Audio/DrvHostCoreAudio.cpp	(revision 68085)
@@ -1888,9 +1888,9 @@
  */
 static DECLCALLBACK(int) drvHostCoreAudioStreamCapture(PPDMIHOSTAUDIO pInterface, PPDMAUDIOBACKENDSTREAM pStream,
-                                                       void *pvBuf, uint32_t cbBuf, uint32_t *pcbRead)
+                                                       void *pvBuf, uint32_t cxBuf, uint32_t *pcxRead)
 {
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
     /* pcbRead is optional. */
 
     PCOREAUDIOSTREAM  pCAStream = (PCOREAUDIOSTREAM)pStream;
@@ -1917,6 +1917,6 @@
     if (ASMAtomicReadU32(&pCAStream->enmStatus) != COREAUDIOSTATUS_INIT)
     {
-        if (pcbRead)
-            *pcbRead = 0;
+        if (pcxRead)
+            *pcxRead = 0;
         return VINF_SUCCESS;
     }
@@ -1931,5 +1931,5 @@
     do
     {
-        size_t cbToWrite = RT_MIN(cbBuf, RTCircBufUsed(pCAStream->pCircBuf));
+        size_t cbToWrite = RT_MIN(cxBuf, RTCircBufUsed(pCAStream->pCircBuf));
 
         uint8_t *pvChunk;
@@ -1964,6 +1964,6 @@
     if (RT_SUCCESS(rc))
     {
-        if (pcbRead)
-            *pcbRead = cbReadTotal;
+        if (pcxRead)
+            *pcxRead = cbReadTotal;
     }
 
@@ -1975,6 +1975,6 @@
  */
 static DECLCALLBACK(int) drvHostCoreAudioStreamPlay(PPDMIHOSTAUDIO pInterface,
-                                                    PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cbBuf,
-                                                    uint32_t *pcbWritten)
+                                                    PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cxBuf,
+                                                    uint32_t *pcxWritten)
 {
     PDRVHOSTCOREAUDIO pThis     = PDMIHOSTAUDIO_2_DRVHOSTCOREAUDIO(pInterface);
@@ -2001,6 +2001,6 @@
     if (ASMAtomicReadU32(&pCAStream->enmStatus) != COREAUDIOSTATUS_INIT)
     {
-        if (pcbWritten)
-            *pcbWritten = 0;
+        if (pcxWritten)
+            *pcxWritten = 0;
         return VINF_SUCCESS;
     }
@@ -2013,5 +2013,5 @@
     AssertRC(rc);
 
-    size_t cbToWrite = RT_MIN(cbBuf, RTCircBufFree(pCAStream->pCircBuf));
+    size_t cbToWrite = RT_MIN(cxBuf, RTCircBufFree(pCAStream->pCircBuf));
     Log3Func(("cbToWrite=%zu\n", cbToWrite));
 
@@ -2030,5 +2030,5 @@
 
         Assert(cbChunk <= cbToWrite);
-        Assert(cbWrittenTotal + cbChunk <= cbBuf);
+        Assert(cbWrittenTotal + cbChunk <= cxBuf);
 
         memcpy(pvChunk, (uint8_t *)pvBuf + cbWrittenTotal, cbChunk);
@@ -2077,6 +2077,6 @@
     if (RT_SUCCESS(rc))
     {
-        if (pcbWritten)
-            *pcbWritten = cbWrittenTotal;
+        if (pcxWritten)
+            *pcxWritten = cbWrittenTotal;
     }
 
@@ -1888,9 +1888,9 @@
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
-    /* pcbRead is optional. */
+    /* pcxRead is optional. */
 
     PCOREAUDIOSTREAM  pCAStream = (PCOREAUDIOSTREAM)pStream;
Index: /trunk/src/VBox/Devices/Audio/DrvHostPulseAudio.cpp
===================================================================
--- /trunk/src/VBox/Devices/Audio/DrvHostPulseAudio.cpp	(revision 68084)
+++ /trunk/src/VBox/Devices/Audio/DrvHostPulseAudio.cpp	(revision 68085)
@@ -827,11 +827,11 @@
  */
 static DECLCALLBACK(int) drvHostPulseAudioStreamCapture(PPDMIHOSTAUDIO pInterface,
-                                                        PPDMAUDIOBACKENDSTREAM pStream, void *pvBuf, uint32_t cbBuf, uint32_t *pcbRead)
-{
-    RT_NOREF(pvBuf, cbBuf);
+                                                        PPDMAUDIOBACKENDSTREAM pStream, void *pvBuf, uint32_t cxBuf, uint32_t *pcxRead)
+{
+    RT_NOREF(pvBuf, cxBuf);
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
     AssertPtrReturn(pvBuf,      VERR_INVALID_POINTER);
-    AssertReturn(cbBuf,         VERR_INVALID_PARAMETER);
+    AssertReturn(cxBuf,         VERR_INVALID_PARAMETER);
     /* pcbRead is optional. */
 
@@ -858,6 +858,6 @@
     if (!cbAvail) /* No data? Bail out. */
     {
-        if (pcbRead)
-            *pcbRead = 0;
+        if (pcxRead)
+            *pcxRead = 0;
         return VINF_SUCCESS;
     }
@@ -865,5 +865,5 @@
     int rc = VINF_SUCCESS;
 
-    size_t cbToRead = RT_MIN(cbAvail, cbBuf);
+    size_t cbToRead = RT_MIN(cbAvail, cxBuf);
 
     Log3Func(("cbToRead=%zu, cbAvail=%zu, offPeekBuf=%zu, cbPeekBuf=%zu\n",
@@ -933,6 +933,6 @@
     if (RT_SUCCESS(rc))
     {
-        if (pcbRead)
-            *pcbRead = cbReadTotal;
+        if (pcxRead)
+            *pcxRead = cbReadTotal;
     }
 
@@ -945,13 +945,13 @@
  */
 static DECLCALLBACK(int) drvHostPulseAudioStreamPlay(PPDMIHOSTAUDIO pInterface,
-                                                     PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cbBuf,
-                                                     uint32_t *pcbWritten)
-{
-    RT_NOREF(pvBuf, cbBuf);
+                                                     PPDMAUDIOBACKENDSTREAM pStream, const void *pvBuf, uint32_t cxBuf,
+                                                     uint32_t *pcxWritten)
+{
+    RT_NOREF(pvBuf, cxBuf);
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
     AssertPtrReturn(pvBuf,      VERR_INVALID_POINTER);
-    AssertReturn(cbBuf,         VERR_INVALID_PARAMETER);
-    /* pcbWritten is optional. */
+    AssertReturn(cxBuf,         VERR_INVALID_PARAMETER);
+    /* pcxWritten is optional. */
 
     PDRVHOSTPULSEAUDIO pThis     = PDMIHOSTAUDIO_2_DRVHOSTPULSEAUDIO(pInterface);
@@ -973,5 +973,5 @@
         }
 
-        size_t cbLeft = RT_MIN(cbWriteable, cbBuf);
+        size_t cbLeft = RT_MIN(cbWriteable, cxBuf);
 
         while (cbLeft)
@@ -999,6 +999,6 @@
     if (RT_SUCCESS(rc))
     {
-        if (pcbWritten)
-            *pcbWritten = cbWrittenTotal;
+        if (pcxWritten)
+            *pcxWritten = cbWrittenTotal;
     }
 
Index: /trunk/src/VBox/Main/src-client/DrvAudioVRDE.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/DrvAudioVRDE.cpp	(revision 68084)
+++ /trunk/src/VBox/Main/src-client/DrvAudioVRDE.cpp	(revision 68085)
@@ -220,11 +220,11 @@
  */
 static DECLCALLBACK(int) drvAudioVRDEStreamCapture(PPDMIHOSTAUDIO pInterface,
-                                                   PPDMAUDIOBACKENDSTREAM pStream, void *pvBuf, uint32_t cbBuf, uint32_t *pcbRead)
+                                                   PPDMAUDIOBACKENDSTREAM pStream, void *pvBuf, uint32_t cxBuf, uint32_t *pcxRead)
 {
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
     AssertPtrReturn(pvBuf,      VERR_INVALID_POINTER);
-    AssertReturn(cbBuf,         VERR_INVALID_PARAMETER);
-    /* pcbRead is optional. */
+    AssertReturn(cxBuf,         VERR_INVALID_PARAMETER);
+    /* pcxRead is optional. */
 
     PVRDESTREAM pStreamVRDE = (PVRDESTREAM)pStream;
@@ -236,5 +236,5 @@
         void *pvData;
 
-        RTCircBufAcquireReadBlock(pStreamVRDE->In.pCircBuf, cbBuf, &pvData, &cbData);
+        RTCircBufAcquireReadBlock(pStreamVRDE->In.pCircBuf, cxBuf, &pvData, &cbData);
 
         if (cbData)
@@ -244,6 +244,6 @@
     }
 
-    if (pcbRead)
-        *pcbRead = (uint32_t)cbData;
+    if (pcxRead)
+        *pcxRead = (uint32_t)cbData;
 
     return VINF_SUCCESS;
@@ -255,11 +255,11 @@
  */
 static DECLCALLBACK(int) drvAudioVRDEStreamPlay(PPDMIHOSTAUDIO pInterface, PPDMAUDIOBACKENDSTREAM pStream,
-                                                const void *pvBuf, uint32_t cbBuf, uint32_t *pcbWritten)
+                                                const void *pvBuf, uint32_t cxBuf, uint32_t *pcxWritten)
 {
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
     AssertPtrReturn(pvBuf,      VERR_INVALID_POINTER);
-    AssertReturn(cbBuf,         VERR_INVALID_PARAMETER);
-    /* pcbWritten is optional. */
+    AssertReturn(cxBuf,         VERR_INVALID_PARAMETER);
+    /* pcxWritten is optional. */
 
     PDRVAUDIOVRDE pDrv        = RT_FROM_MEMBER(pInterface, DRVAUDIOVRDE, IHostAudio);
@@ -271,5 +271,5 @@
     /* Note: We get the number of *samples* in cbBuf
      *       (since we specified PDMAUDIOSTREAMLAYOUT_RAW as the audio data layout) on stream creation. */
-    uint32_t csLive           = cbBuf;
+    uint32_t csLive           = cxBuf;
 
     PPDMAUDIOPCMPROPS pProps  = &pStreamVRDE->pCfg->Props;
@@ -328,6 +328,6 @@
         /* Return samples instead of bytes here
          * (since we specified PDMAUDIOSTREAMLAYOUT_RAW as the audio data layout). */
-        if (pcbWritten)
-            *pcbWritten = csWritten;
+        if (pcxWritten)
+            *pcxWritten = csWritten;
     }
 
Index: /trunk/src/VBox/Main/src-client/DrvAudioVideoRec.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/DrvAudioVideoRec.cpp	(revision 68084)
+++ /trunk/src/VBox/Main/src-client/DrvAudioVideoRec.cpp	(revision 68085)
@@ -508,10 +508,10 @@
  */
 static DECLCALLBACK(int) drvAudioVideoRecStreamCapture(PPDMIHOSTAUDIO pInterface, PPDMAUDIOBACKENDSTREAM pStream,
-                                                       void *pvBuf, uint32_t cbBuf, uint32_t *pcbRead)
-{
-    RT_NOREF(pInterface, pStream, pvBuf, cbBuf);
-
-    if (pcbRead)
-        *pcbRead = 0;
+                                                       void *pvBuf, uint32_t cxBuf, uint32_t *pcxRead)
+{
+    RT_NOREF(pInterface, pStream, pvBuf, cxBuf);
+
+    if (pcxRead)
+        *pcxRead = 0;
 
     return VINF_SUCCESS;
@@ -523,11 +523,11 @@
  */
 static DECLCALLBACK(int) drvAudioVideoRecStreamPlay(PPDMIHOSTAUDIO pInterface, PPDMAUDIOBACKENDSTREAM pStream,
-                                                    const void *pvBuf, uint32_t cbBuf, uint32_t *pcbWritten)
+                                                    const void *pvBuf, uint32_t cxBuf, uint32_t *pcxWritten)
 {
     AssertPtrReturn(pInterface, VERR_INVALID_POINTER);
     AssertPtrReturn(pStream,    VERR_INVALID_POINTER);
     AssertPtrReturn(pvBuf,      VERR_INVALID_POINTER);
-    AssertReturn(cbBuf,         VERR_INVALID_PARAMETER);
-    /* pcbWritten is optional. */
+    AssertReturn(cxBuf,         VERR_INVALID_PARAMETER);
+    /* pcxWritten is optional. */
 
     PDRVAUDIOVIDEOREC pThis     = PDMIHOSTAUDIO_2_DRVAUDIOVIDEOREC(pInterface);
@@ -551,5 +551,5 @@
     size_t cbCircBuf;
 
-    uint32_t cbToWrite = cbBuf;
+    uint32_t cbToWrite = cxBuf;
 
     /*
@@ -692,6 +692,6 @@
      * encoder actually did process those.
      */
-    if (pcbWritten)
-        *pcbWritten = cbWrittenTotal;
+    if (pcxWritten)
+        *pcxWritten = cbWrittenTotal;
 
     LogFlowFunc(("csReadTotal=%RU32, rc=%Rrc\n", cbWrittenTotal, rc));
